<p align="center">
    <img src="docs/img/import-linter-logo-text.png" alt="Import Linter">
</p>

<p align="center">
    <strong>Lint your Python architecture.</strong>
</p>

<p align="center">
  <a href="https://pypi.org/project/import-linter" target="_blank">
      <img src="https://img.shields.io/pypi/v/import-linter.svg" alt="Package version">
  </a>
  <a href="https://pypi.org/project/import-linter" target="_blank">
      <img src="https://img.shields.io/pypi/pyversions/import-linter.svg" alt="Python versions">
  </a>
  <a href="https://github.com/seddonym/import-linter/actions/workflows/main.yml" target="_blank">
      <img src="https://github.com/seddonym/import-linter/actions/workflows/main.yml/badge.svg" alt="CI status">
  </a>
  <a href="https://opensource.org/licenses/BSD-2-Clause" target="_blank">
      <img src="https://img.shields.io/badge/License-BSD_2--Clause-orange.svg" alt="BSD license">
  </a>
</p>


**Import Linter** is a command-line tool for imposing constraints on the imports between your Python modules.

<p align="center">
    <a href="https://import-linter.readthedocs.io/">Get started</a>.
</p>